--[[
Interface: 1.7.1.0 b10490

Copyright (C) GtX (Andy), 2020

Author: GtX | Andy
Date: 20.12.2020

Contact:
https://forum.giants-software.com
https://github.com/GtX-Andy

Important:
Not to be added to any mods / maps or modified from its current release form.
No changes are to be made to this script without permission from GtX | Andy

Darf nicht zu Mods / Maps hinzugefügt oder von der aktuellen Release-Form geändert werden.
An diesem Skript dürfen ohne Genehmigung von GtX | Andy keine Änderungen vorgenommen werden
]]


StoreSalesEvent = {}
local StoreSalesEvent_mt = Class(StoreSalesEvent, Event)

InitEventClass(StoreSalesEvent, "StoreSalesEvent")

function StoreSalesEvent:emptyNew()
    local self = Event:new(StoreSalesEvent_mt)

    return self
end

function StoreSalesEvent:new(sales)
    local self = StoreSalesEvent:emptyNew()

    self.sales = sales
    self.salesChanged = false

    return self
end

function StoreSalesEvent:readStream(streamId, connection)
    local numberOfSales = streamReadUInt8(streamId)

    for i = 1, numberOfSales do
        local sale = g_storeSalesManager:getSaleById(i)

        sale.isValid = streamReadBool(streamId)

        if sale.isValid then
            sale.xmlFilename = NetworkUtil.convertFromNetworkFilename(streamReadString(streamId))
            sale.brandIndex = StoreSale.getValidBrandIndex(sale.xmlFilename)

            sale.remainingHours = streamReadUInt8(streamId)
            sale.discountPercent = streamReadUInt8(streamId)

            sale.startDay = streamReadInt32(streamId)
            sale.startHour = streamReadUInt8(streamId)

            local isActive = streamReadBool(streamId)

            sale.isStarting = isActive and not sale.isActive
            sale.isStopping = not isActive and sale.isActive
        else
            sale.isStopping = sale.isActive
        end

        if sale.isStarting or sale.isStopping then
            self.salesChanged = true
        end
    end

    self:run(connection)
end

function StoreSalesEvent:writeStream(streamId, connection)
    local numberOfSales = #self.sales

    streamWriteUInt8(streamId, numberOfSales)

    for i = 1, numberOfSales do
        local sale = self.sales[i]

        if streamWriteBool(streamId, sale.isValid) then
            streamWriteString(streamId, NetworkUtil.convertToNetworkFilename(sale.xmlFilename))

            streamWriteUInt8(streamId, sale.remainingHours)
            streamWriteUInt8(streamId, sale.discountPercent)

            streamWriteInt32(streamId, sale.startDay)
            streamWriteUInt8(streamId, sale.startHour)

            streamWriteBool(streamId, sale.isActive)
        end
    end
end

function StoreSalesEvent:run(connection)
    if connection:getIsServer() and self.salesChanged then
        for _, sale in ipairs(g_storeSalesManager:getSales()) do
            if sale.isStarting then
                sale:setActive(true)
            elseif sale.isStopping then
                sale:setActive(false)
            end

            sale.isStarting = false
            sale.isStopping = false
        end
    end
end
