--[[
Interface: 1.7.1.0 b10490

Copyright (C) GtX (Andy), 2021

Author: GtX | Andy
Date: 15.02.2021

Contact:
https://forum.giants-software.com
https://github.com/GtX-Andy

Important:
Not to be added to any mods / maps or modified from its current release form.
No changes are to be made to this script without permission from GtX | Andy

Darf nicht zu Mods / Maps hinzugefügt oder von der aktuellen Release-Form geändert werden.
An diesem Skript dürfen ohne Genehmigung von GtX | Andy keine Änderungen vorgenommen werden
]]


StoreSalesRender = {}
local StoreSalesRender_mt = Class(StoreSalesRender)

function StoreSalesRender:new(sales)
    local self = setmetatable({}, StoreSalesRender_mt)

    self.sales = sales
    self.lineIndex = 0

    return self
end

function StoreSalesRender:delete()
    self.sales = nil
    self.lineIndex = 0
end

function StoreSalesRender:update(dt)
    if self.sales ~= nil then
        self.lineIndex = 0

        local posX = 0.1
        local posY = 0.95

        local textSize = getCorrectTextSize(0.014)

        setTextColor(1, 1, 1, 1)
        setTextBold(false)

        for id, sale in ipairs (self.sales) do
            local isValid = sale:getIsValid()
            local isActive = sale:getIsActive()

            self:renderSaleDataValue(posX, posY, textSize, "Sale ID", id)
            self:renderSaleDataValue(posX, posY, textSize, "Active", isActive)
            self:renderSaleDataValue(posX, posY, textSize, "Valid", isValid)
            self:renderSaleDataValue(posX, posY, textSize, "Brand Sale", sale.isBrandSale)

            if isValid then
                local startCountDown = "Started"

                if sale.isBrandSale then
                    local brandTitle = "N/A"
                    local brand = g_brandManager:getBrandByIndex(sale.brandIndex)

                    if brand ~= nil then
                        brandTitle = brand.title
                    end

                    self:renderSaleDataValue(posX, posY, textSize, "Brand Title", brandTitle)
                elseif sale.xmlFilename ~= nil then
                    self:renderSaleDataValue(posX, posY, textSize, "XML Filename", sale.xmlFilename)
                end

                if sale.startDay > 0 then
                    self:renderSaleDataValue(posX, posY, textSize, "Start Day", sale.startDay)
                end

                if sale.startHour > 0 then
                    self:renderSaleDataValue(posX, posY, textSize, "Start Hour", sale.startHour)
                end

                if sale.remainingHours > 0 then
                    self:renderSaleDataValue(posX, posY, textSize, "Remaining Hours", sale.remainingHours)
                end

                if sale.discountPercent > 0 then
                    self:renderSaleDataValue(posX, posY, textSize, "Discount Percent", sale.discountPercent)
                end

                if not isActive then
                    local hoursToStart = math.max(sale.startDay - g_currentMission.environment.currentDay, 0) * 24
                    hoursToStart = hoursToStart + (sale.startHour - g_currentMission.environment.currentHour)

                    if hoursToStart > 0 then
                        local minutes = g_currentMission.environment.currentMinute

                        if minutes > 0 then
                            hoursToStart = hoursToStart - 1
                            minutes = 60 - minutes
                        end

                        local hours = math.max(hoursToStart % 24, 0)
                        local days = math.max(math.floor(hoursToStart / 24))

                        startCountDown = string.format("%02.f:%02.f:%02.f  (Days:Hours:Minutes)", days, hours, minutes)
                    end
                end

                self:renderSaleDataValue(posX, posY, textSize, "Starts In", startCountDown)
                self.lineIndex = self.lineIndex + 1 -- Add a blank line
            end
        end
    end
end

function StoreSalesRender:renderSaleDataValue(posX, posY, textSize, name, value)
    local yOffset = self.lineIndex * textSize * 1.05

    setTextAlignment(RenderText.ALIGN_RIGHT)
    renderText(posX, posY - yOffset, textSize, tostring(name) .. ":")

    setTextAlignment(RenderText.ALIGN_LEFT)
    renderText(posX, posY - yOffset, textSize, " " .. tostring(value))

    self.lineIndex = self.lineIndex + 1
end
